@@ -3,7 +3,7 @@ package Bencher::Scenario::URIEscaping;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-18'; # DATE
 our $DIST = 'Bencher-Scenario-URIEscaping'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -17,7 +17,8 @@ $ENV{PERL_URI_XSESCAPE} = 0;
 our $scenario = {
     summary => 'Benchmark URI escaping using various modules',
 
-    #precision => 0.001,
+    precision => 0.001,
+    module_startup_precision => 0.05,
 
     participants => [
         {fcall_template => 'URI::Escape::uri_escape(<str>)', tags=>['escape']},
@@ -97,7 +98,7 @@ Bencher::Scenario::URIEscaping - Benchmark URI escaping using various modules
 
 =head1 VERSION
 
-This document describes version 0.005 of Bencher::Scenario::URIEscaping (from Perl distribution Bencher-Scenario-URIEscaping), released on 2020-06-18.
+This document describes version 0.006 of Bencher::Scenario::URIEscaping (from Perl distribution Bencher-Scenario-URIEscaping), released on 2020-06-18.
 
 =head1 SYNOPSIS
 
@@ -256,43 +257,43 @@ Run on: perl: I<< v5.30.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (
 Benchmark with default options (C<< bencher -m URIEscaping >>):
 
  #table1#
- +--------------------------------+-----------+--------------+--------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | participant                    | dataset   | ds_tags      | p_tags       | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
- +--------------------------------+-----------+--------------+--------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | URI::Encode::uri_decode        | u_ascii53 | unescape     | unescape     |      3600 |  280      |                 0.00% |            834128.52% | 4.5e-07 |      23 |
- | URI::Encode::uri_encode        | ascii53   | escape       | escape       |      3600 |  280      |                 0.32% |            831493.00% | 4.2e-07 |      21 |
- | URI::Encode::uri_encode        | ascii66   | escape       | escape       |      3600 |  280      |                 1.28% |            823568.11% | 6.6e-07 |      22 |
- | URI::Encode::uri_decode        | u_ascii66 | unescape     | unescape     |      3700 |  270      |                 2.58% |            813173.26% | 4.8e-07 |      20 |
- | URI::Encode::uri_encode        | empty     | escape       | escape       |      3800 |  260      |                 6.14% |            785883.33% | 4.8e-07 |      20 |
- | URI::Escape::uri_escape_utf8   | ascii53   | escape       | escape, utf8 |    140000 |    7.15   |              3816.41% |             21200.83% | 2.7e-09 |      30 |
- | URI::Escape::uri_escape        | ascii53   | escape       | escape       |    144000 |    6.93   |              3936.82% |             20565.50% | 3.3e-09 |      20 |
- | URI::Escape::uri_unescape      | u_ascii53 | unescape     | unescape     |    164390 |    6.083  |              4501.06% |             18031.23% | 2.5e-11 |      24 |
- | URI::Escape::uri_escape_utf8   | utf36     | escape, utf8 | escape, utf8 |    168000 |    5.97   |              4589.58% |             17688.97% | 1.5e-09 |      26 |
- | URI::Escape::uri_escape_utf8   | ascii66   | escape       | escape, utf8 |    219000 |    4.57   |              6026.25% |             13517.27% | 1.5e-09 |      24 |
- | URI::Escape::uri_escape        | ascii66   | escape       | escape       |    230000 |    4.35   |              6332.56% |             12868.85% | 1.6e-09 |      23 |
- | URI::Escape::uri_unescape      | u_ascii66 | unescape     | unescape     |    280000 |    3.6    |              7604.67% |             10727.56% |   5e-09 |      20 |
- | URI::Escape::uri_escape_utf8   | empty     | escape       | escape, utf8 |   1700000 |    0.59   |             47092.42% |              1667.72% | 8.3e-10 |      20 |
- | URI::Escape::XS::uri_escape    | ascii53   | escape       | escape       |   2500000 |    0.41   |             68577.90% |              1114.70% | 5.5e-10 |      26 |
- | URI::Escape::XS::uri_escape    | ascii66   | escape       | escape       |   2462000 |    0.4062 |             68799.80% |              1110.79% | 2.4e-11 |      31 |
- | URI::Escape::uri_escape        | empty     | escape       | escape       |   2508000 |    0.3987 |             70104.43% |              1088.28% | 2.2e-11 |      20 |
- | URI::XSEscape::uri_escape_utf8 | ascii66   | escape       | escape, utf8 |   2690000 |    0.372  |             75194.07% |              1007.96% | 2.1e-10 |      20 |
- | URI::XSEscape::uri_escape_utf8 | ascii53   | escape       | escape, utf8 |   2730000 |    0.366  |             76397.44% |               990.53% | 1.7e-10 |      31 |
- | URI::Escape::XS::uri_unescape  | u_ascii53 | unescape     | unescape     |   2862000 |    0.3494 |             79994.19% |               941.56% | 1.7e-11 |      20 |
- | URI::XSEscape::uri_escape_utf8 | utf36     | escape, utf8 | escape, utf8 |   2976000 |    0.336  |             83197.91% |               901.50% | 2.4e-11 |      20 |
- | URI::Escape::XS::uri_escape    | empty     | escape       | escape       |   3051000 |    0.3278 |             85291.12% |               876.95% | 5.8e-12 |      23 |
- | URI::Escape::XS::uri_unescape  | u_ascii66 | unescape     | unescape     |   3150000 |    0.317  |             88177.67% |               845.01% | 1.1e-10 |      20 |
- | URI::XSEscape::uri_escape_utf8 | empty     | escape       | escape, utf8 |   3750000 |    0.267  |            104754.54% |               695.61% | 8.6e-11 |      32 |
- | URI::XSEscape::uri_unescape    | u_ascii53 | unescape     | unescape     |   4920000 |    0.203  |            137523.90% |               506.17% | 2.4e-11 |      20 |
- | URI::XSEscape::uri_unescape    | u_ascii66 | unescape     | unescape     |   4983000 |    0.2007 |            139356.66% |               498.20% | 1.7e-11 |      20 |
- | URI::XSEscape::uri_escape      | ascii66   | escape       | escape       |   5500000 |    0.18   |            152651.86% |               446.13% | 2.7e-10 |      27 |
- | URI::XSEscape::uri_escape      | ascii53   | escape       | escape       |   5700000 |    0.18   |            159472.86% |               422.79% | 2.6e-10 |      29 |
- | URI::XSEscape::uri_escape      | empty     | escape       | escape       |  10000000 |    0.1    |            278783.59% |               199.13% | 1.6e-10 |      20 |
- | URI::Encode::XS::uri_encode    | ascii53   | escape       | escape       |  12000000 |    0.083  |            335845.34% |               148.32% | 2.1e-10 |      20 |
- | URI::Encode::XS::uri_encode    | ascii66   | escape       | escape       |  12000000 |    0.0831 |            336757.14% |               147.65% | 2.4e-11 |      24 |
- | URI::Encode::XS::uri_decode    | u_ascii66 | unescape     | unescape     |  12000000 |    0.083  |            336990.50% |               147.48% | 2.1e-10 |      20 |
- | URI::Encode::XS::uri_decode    | u_ascii53 | unescape     | unescape     |  12700000 |    0.0789 |            354725.57% |               135.11% |   6e-11 |      23 |
- | URI::Encode::XS::uri_encode    | empty     | escape       | escape       |  30000000 |    0.034  |            834128.52% |                 0.00% | 7.8e-11 |      20 |
- +--------------------------------+-----------+--------------+--------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
+ +--------------------------------+-----------+--------------+--------------+-----------+------------+-----------------------+-----------------------+---------+---------+
+ | participant                    | dataset   | ds_tags      | p_tags       | rate (/s) | time (μs)  | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
+ +--------------------------------+-----------+--------------+--------------+-----------+------------+-----------------------+-----------------------+---------+---------+
+ | URI::Encode::uri_encode        | ascii53   | escape       | escape       |      3410 | 293        |                 0.00% |            982933.13% | 2.8e-07 |     104 |
+ | URI::Encode::uri_decode        | u_ascii53 | unescape     | unescape     |      3480 | 288        |                 1.99% |            963720.81% | 2.1e-07 |      20 |
+ | URI::Encode::uri_encode        | ascii66   | escape       | escape       |      3550 | 282        |                 4.00% |            945139.90% | 2.1e-07 |      20 |
+ | URI::Encode::uri_decode        | u_ascii66 | unescape     | unescape     |      3550 | 282        |                 4.06% |            944547.08% | 2.4e-07 |      24 |
+ | URI::Encode::uri_encode        | empty     | escape       | escape       |      3680 | 272        |                 7.92% |            910775.23% | 2.1e-07 |      20 |
+ | URI::Escape::uri_escape        | ascii53   | escape       | escape       |    132879 |   7.52563  |              3796.93% |             25125.81% | 5.5e-12 |      20 |
+ | URI::Escape::uri_escape_utf8   | ascii53   | escape       | escape, utf8 |    138000 |   7.27     |              3933.67% |             24270.69% |   3e-09 |      24 |
+ | URI::Escape::uri_escape_utf8   | utf36     | escape, utf8 | escape, utf8 |    160000 |   6.1      |              4728.44% |             20259.23% | 6.1e-09 |      24 |
+ | URI::Escape::uri_unescape      | u_ascii53 | unescape     | unescape     |    165285 |   6.05014  |              4747.31% |             20179.99% | 4.8e-12 |      22 |
+ | URI::Escape::uri_escape_utf8   | ascii66   | escape       | escape, utf8 |    214000 |   4.67     |              6179.44% |             15554.80% | 4.6e-09 |      42 |
+ | URI::Escape::uri_escape        | ascii66   | escape       | escape       |    226080 |   4.4232   |              6530.22% |             14726.55% | 5.7e-12 |      20 |
+ | URI::Escape::uri_unescape      | u_ascii66 | unescape     | unescape     |    274380 |   3.64458  |              7946.72% |             12116.57% |   0     |      20 |
+ | URI::Escape::uri_escape_utf8   | empty     | escape       | escape, utf8 |   1730000 |   0.576    |             50780.41% |              1832.05% | 5.7e-10 |      24 |
+ | URI::Escape::uri_escape        | empty     | escape       | escape       |   2400610 |   0.41656  |             70302.45% |              1296.31% |   0     |      20 |
+ | URI::Escape::XS::uri_escape    | ascii53   | escape       | escape       |   2440000 |   0.41     |             71373.22% |              1275.39% | 2.1e-10 |      20 |
+ | URI::Escape::XS::uri_escape    | ascii66   | escape       | escape       |   2438740 |   0.410048 |             71420.59% |              1274.48% |   0     |      20 |
+ | URI::XSEscape::uri_escape_utf8 | ascii66   | escape       | escape, utf8 |   2663000 |   0.3755   |             78006.67% |              1158.58% | 5.7e-12 |      25 |
+ | URI::XSEscape::uri_escape_utf8 | ascii53   | escape       | escape, utf8 |   2726030 |   0.366834 |             79845.81% |              1129.62% |   0     |      20 |
+ | URI::Escape::XS::uri_unescape  | u_ascii53 | unescape     | unescape     |   2900000 |   0.35     |             84295.89% |              1064.79% | 3.9e-10 |      23 |
+ | URI::XSEscape::uri_escape_utf8 | utf36     | escape, utf8 | escape, utf8 |   2890000 |   0.346    |             84571.59% |              1061.00% |   3e-10 |      21 |
+ | URI::Escape::XS::uri_escape    | empty     | escape       | escape       |   3000000 |   0.334    |             87784.28% |              1018.55% |   1e-10 |      20 |
+ | URI::Escape::XS::uri_unescape  | u_ascii66 | unescape     | unescape     |   3187000 |   0.3138   |             93354.20% |               951.89% | 4.8e-12 |      20 |
+ | URI::XSEscape::uri_escape_utf8 | empty     | escape       | escape, utf8 |   3800000 |   0.27     |            110522.39% |               788.64% | 3.1e-10 |      37 |
+ | URI::XSEscape::uri_unescape    | u_ascii53 | unescape     | unescape     |   4852000 |   0.2061   |            142183.42% |               590.90% | 1.7e-11 |      20 |
+ | URI::XSEscape::uri_unescape    | u_ascii66 | unescape     | unescape     |   4986000 |   0.2006   |            146111.46% |               572.34% | 5.8e-12 |      20 |
+ | URI::XSEscape::uri_escape      | ascii66   | escape       | escape       |   5293000 |   0.1889   |            155112.72% |               533.35% | 5.5e-12 |      20 |
+ | URI::XSEscape::uri_escape      | ascii53   | escape       | escape       |   5670000 |   0.176    |            166067.23% |               491.59% |   1e-10 |      21 |
+ | URI::XSEscape::uri_escape      | empty     | escape       | escape       |   9980000 |   0.1      |            292476.83% |               235.99% | 5.2e-11 |      20 |
+ | URI::Encode::XS::uri_decode    | u_ascii66 | unescape     | unescape     |  12000000 |   0.082    |            356094.65% |               175.98% | 1.2e-10 |      56 |
+ | URI::Encode::XS::uri_encode    | ascii66   | escape       | escape       |  12550000 |   0.07966  |            368038.76% |               167.03% | 5.8e-12 |      20 |
+ | URI::Encode::XS::uri_encode    | ascii53   | escape       | escape       |  13000000 |   0.075    |            389431.92% |               152.36% | 1.1e-10 |      45 |
+ | URI::Encode::XS::uri_decode    | u_ascii53 | unescape     | unescape     |  13500000 |   0.07407  |            395844.46% |               148.28% | 5.7e-12 |      26 |
+ | URI::Encode::XS::uri_encode    | empty     | escape       | escape       |  33500000 |   0.0298   |            982933.13% |                 0.00% | 4.9e-12 |      20 |
+ +--------------------------------+-----------+--------------+--------------+-----------+------------+-----------------------+-----------------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m URIEscaping --module-startup >>):
@@ -301,12 +302,12 @@ Benchmark module startup overhead (C<< bencher -m URIEscaping --module-startup >
  +---------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
  | participant         | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
  +---------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
- | URI::Encode         |      20   |              15   |                 0.00% |               241.33% |   0.00021 |      20 |
- | URI::Escape         |      10   |               5   |                71.67% |                98.83% |   0.00024 |      20 |
- | URI::Encode::XS     |       8   |               3   |               118.60% |                56.14% |   0.00012 |      20 |
- | URI::Escape::XS     |       8   |               3   |               128.19% |                49.58% |   0.00011 |      21 |
- | URI::XSEscape       |       5.8 |               0.8 |               198.63% |                14.30% | 2.2e-05   |      20 |
- | perl -e1 (baseline) |       5   |               0   |               241.33% |                 0.00% |   0.00014 |      20 |
+ | URI::Encode         |        17 |                12 |                 0.00% |               235.22% | 9.2e-05   |      20 |
+ | URI::Escape::XS     |        10 |                 5 |                75.36% |                91.16% |   0.00033 |      20 |
+ | URI::Escape         |         9 |                 4 |                85.44% |                80.77% |   0.00015 |      20 |
+ | URI::XSEscape       |         8 |                 3 |               117.22% |                54.32% |   0.00018 |      22 |
+ | URI::Encode::XS     |         7 |                 2 |               144.39% |                37.17% |   0.00014 |      20 |
+ | perl -e1 (baseline) |         5 |                 0 |               235.22% |                 0.00% |   0.00016 |      20 |
  +---------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
 
 
